@@ -45,7 +45,9 @@ class SecurityGroupsTestJSON(base.BaseSecurityGroupsTest):
             security_group_list.append(body)
         # Fetch all Security Groups and verify the list
         # has all created Security Groups
-        fetched_list = self.client.list_security_groups()['security_groups']
+        fetched_list = (
+            self.reader_security_groups_client.list_security_groups()
+            ['security_groups'])
         # Now check if all the created Security Groups are in fetched list
         missing_sgs = \
             [sg for sg in security_group_list if sg not in fetched_list]
@@ -58,7 +60,9 @@ class SecurityGroupsTestJSON(base.BaseSecurityGroupsTest):
             self.client.delete_security_group(sg['id'])
             self.client.wait_for_resource_deletion(sg['id'])
         # Now check if all the created Security Groups are deleted
-        fetched_list = self.client.list_security_groups()['security_groups']
+        fetched_list = (
+            self.reader_security_groups_client.list_security_groups()
+            ['security_groups'])
         deleted_sgs = [sg for sg in security_group_list if sg in fetched_list]
         self.assertFalse(deleted_sgs,
                          "Failed to delete Security Group %s "
@@ -80,8 +84,9 @@ class SecurityGroupsTestJSON(base.BaseSecurityGroupsTest):
                          "The created Security Group name is "
                          "not equal to the requested name")
         # Now fetch the created Security Group by its 'id'
-        fetched_group = (self.client.show_security_group(securitygroup['id'])
-                         ['security_group'])
+        fetched_group = (
+            self.reader_security_groups_client.show_security_group(
+                securitygroup['id'])['security_group'])
         self.assertEqual(securitygroup, fetched_group,
                          "The fetched Security Group is different "
                          "from the created Group")
@@ -144,8 +149,9 @@ class SecurityGroupsTestJSON(base.BaseSecurityGroupsTest):
                                           name=s_new_name,
                                           description=s_new_des)
         # get the security group
-        fetched_group = (self.client.show_security_group(securitygroup_id)
-                         ['security_group'])
+        fetched_group = (
+            self.reader_security_groups_client.show_security_group(
+                securitygroup_id)['security_group'])
         self.assertEqual(s_new_name, fetched_group['name'])
         self.assertEqual(s_new_des, fetched_group['description'])
 
@@ -170,7 +176,7 @@ class SecurityGroupsTestJSON(base.BaseSecurityGroupsTest):
 
         # list security groups for a server
         fetched_groups = (
-            self.servers_client.list_security_groups_by_server(
+            self.reader_servers_client.list_security_groups_by_server(
                 server_id)['security_groups'])
         fetched_security_groups_ids = [i['id'] for i in fetched_groups]
         # verifying the security groups ids in list
