@@ -14,9 +14,13 @@
 #    under the License.
 
 from tempest.api.compute import base
+from tempest import config
 from tempest.lib import decorators
 
 
+CONF = config.CONF
+
+
 class AZV2TestJSON(base.BaseV2ComputeTest):
     """Tests Availability Zone API List"""
 
@@ -24,9 +28,14 @@ class AZV2TestJSON(base.BaseV2ComputeTest):
     def setup_clients(cls):
         super(AZV2TestJSON, cls).setup_clients()
         cls.client = cls.availability_zone_client
+        if CONF.enforce_scope.nova:
+            cls.reader_az_client = (
+                cls.os_project_reader.availability_zone_client)
+        else:
+            cls.reader_az_client = cls.client
 
     @decorators.idempotent_id('a8333aa2-205c-449f-a828-d38c2489bf25')
     def test_get_availability_zone_list_with_non_admin_user(self):
         """List of availability zone with non-administrator user"""
-        availability_zone = self.client.list_availability_zones()
+        availability_zone = self.reader_az_client.list_availability_zones()
         self.assertNotEmpty(availability_zone['availabilityZoneInfo'])
