@@ -28,16 +28,9 @@ class ServersTestJSON(base.BaseV2ComputeTest):
     """Test servers API"""
     create_default_network = True
 
-    credentials = ['primary', 'project_reader']
-
     @classmethod
     def setup_clients(cls):
         super(ServersTestJSON, cls).setup_clients()
-        cls.client = cls.servers_client
-        if CONF.enforce_scope.nova:
-            cls.reader_client = cls.os_project_reader.servers_client
-        else:
-            cls.reader_client = cls.client
 
     @decorators.idempotent_id('b92d5ec7-b1dd-44a2-87e4-45e888c46ef0')
     @testtools.skipUnless(CONF.compute_feature_enabled.
@@ -71,9 +64,9 @@ class ServersTestJSON(base.BaseV2ComputeTest):
         id2 = server['id']
         self.addCleanup(self.delete_server, id2)
         self.assertNotEqual(id1, id2, "Did not create a new server")
-        server = self.reader_client.show_server(id1)['server']
+        server = self.reader_servers_client.show_server(id1)['server']
         name1 = server['name']
-        server = self.reader_client.show_server(id2)['server']
+        server = self.reader_servers_client.show_server(id2)['server']
         name2 = server['name']
         self.assertEqual(name1, name2)
 
@@ -88,7 +81,7 @@ class ServersTestJSON(base.BaseV2ComputeTest):
         server = self.create_test_server(key_name=key_name,
                                          wait_until='ACTIVE')
         self.addCleanup(self.delete_server, server['id'])
-        server = self.reader_client.show_server(server['id'])['server']
+        server = self.reader_servers_client.show_server(server['id'])['server']
         self.assertEqual(key_name, server['key_name'])
 
     def _update_server_name(self, server_id, status, prefix_name='server'):
@@ -97,12 +90,12 @@ class ServersTestJSON(base.BaseV2ComputeTest):
             prefix=CONF.resource_name_prefix, name=prefix_name)
 
         # Update the server with a new name
-        self.client.update_server(server_id,
-                                  name=new_name)
-        waiters.wait_for_server_status(self.client, server_id, status)
+        self.servers_client.update_server(server_id,
+                                          name=new_name)
+        waiters.wait_for_server_status(self.servers_client, server_id, status)
 
         # Verify the name of the server has changed
-        server = self.reader_client.show_server(server_id)['server']
+        server = self.reader_servers_client.show_server(server_id)['server']
         self.assertEqual(new_name, server['name'])
         return server
 
@@ -116,8 +109,9 @@ class ServersTestJSON(base.BaseV2ComputeTest):
         self._update_server_name(server['id'], 'ACTIVE', prefix_name)
 
         # stop server and check server name update again
-        self.client.stop_server(server['id'])
-        waiters.wait_for_server_status(self.client, server['id'], 'SHUTOFF')
+        self.servers_client.stop_server(server['id'])
+        waiters.wait_for_server_status(self.servers_client, server['id'],
+                                       'SHUTOFF')
         # Update instance name with non-ASCII characters
         updated_server = self._update_server_name(server['id'],
                                                   'SHUTOFF',
@@ -131,13 +125,14 @@ class ServersTestJSON(base.BaseV2ComputeTest):
         self.addCleanup(self.delete_server, server['id'])
 
         # Update the IPv4 and IPv6 access addresses
-        self.client.update_server(server['id'],
-                                  accessIPv4='1.1.1.1',
-                                  accessIPv6='::babe:202:202')
-        waiters.wait_for_server_status(self.client, server['id'], 'ACTIVE')
+        self.servers_client.update_server(server['id'],
+                                          accessIPv4='1.1.1.1',
+                                          accessIPv6='::babe:202:202')
+        waiters.wait_for_server_status(self.servers_client, server['id'],
+                                       'ACTIVE')
 
         # Verify the access addresses have been updated
-        server = self.reader_client.show_server(server['id'])['server']
+        server = self.reader_servers_client.show_server(server['id'])['server']
         self.assertEqual('1.1.1.1', server['accessIPv4'])
         self.assertEqual('::babe:202:202', server['accessIPv6'])
 
@@ -147,7 +142,7 @@ class ServersTestJSON(base.BaseV2ComputeTest):
         server = self.create_test_server(accessIPv6='2001:2001::3',
                                          wait_until='ACTIVE')
         self.addCleanup(self.delete_server, server['id'])
-        server = self.reader_client.show_server(server['id'])['server']
+        server = self.reader_servers_client.show_server(server['id'])['server']
         self.assertEqual('2001:2001::3', server['accessIPv6'])
 
     @decorators.related_bug('1730756')
@@ -180,22 +175,16 @@ class ServerShowV247Test(base.BaseV2ComputeTest):
     # also. 2.47 APIs schema are on top of 2.9->2.19->2.26 schema so
     # below tests cover all of the schema.
 
-    credentials = ['primary', 'project_reader']
-
     @classmethod
     def setup_clients(cls):
         super(ServerShowV247Test, cls).setup_clients()
-        if CONF.enforce_scope.nova:
-            cls.reader_client = cls.os_project_reader.servers_client
-        else:
-            cls.reader_client = cls.servers_client
 
     @decorators.idempotent_id('88b0bdb2-494c-11e7-a919-92ebcb67fe33')
     def test_show_server(self):
         """Test getting server detail"""
         server = self.create_test_server()
         # All fields will be checked by API schema
-        self.reader_client.show_server(server['id'])
+        self.reader_servers_client.show_server(server['id'])
 
     @decorators.idempotent_id('8de397c2-57d0-4b90-aa30-e5d668f21a8b')
     def test_update_rebuild_list_server(self):
@@ -210,7 +199,7 @@ class ServerShowV247Test(base.BaseV2ComputeTest):
         waiters.wait_for_server_status(self.servers_client,
                                        server['id'], 'ACTIVE')
         # Checking list details API response schema
-        self.servers_client.list_servers(detail=True)
+        self.reader_servers_client.list_servers(detail=True)
 
 
 class ServerShowV263Test(base.BaseV2ComputeTest):
@@ -219,15 +208,9 @@ class ServerShowV263Test(base.BaseV2ComputeTest):
     min_microversion = '2.63'
     max_microversion = 'latest'
 
-    credentials = ['primary', 'project_reader']
-
     @classmethod
     def setup_clients(cls):
         super(ServerShowV263Test, cls).setup_clients()
-        if CONF.enforce_scope.nova:
-            cls.reader_client = cls.os_project_reader.servers_client
-        else:
-            cls.reader_client = cls.servers_client
 
     @testtools.skipUnless(CONF.compute.certified_image_ref,
                           '``[compute]/certified_image_ref`` required to test '
@@ -245,7 +228,7 @@ class ServerShowV263Test(base.BaseV2ComputeTest):
             wait_until='ACTIVE')
 
         # Check show API response schema
-        self.reader_client.show_server(server['id'])['server']
+        self.reader_servers_client.show_server(server['id'])['server']
 
         # Check update API response schema
         self.servers_client.update_server(server['id'])
@@ -260,7 +243,7 @@ class ServerShowV263Test(base.BaseV2ComputeTest):
 
         # Check list details API response schema
         params = {'trusted_image_certificates': trusted_certs}
-        servers = self.servers_client.list_servers(
+        servers = self.reader_servers_client.list_servers(
             detail=True, **params)['servers']
         self.assertNotEmpty(servers)
 
@@ -275,13 +258,17 @@ class ServersListShow296Test(base.BaseV2ComputeTest):
     min_microversion = '2.96'
     max_microversion = 'latest'
 
+    @classmethod
+    def setup_clients(cls):
+        super(ServersListShow296Test, cls).setup_clients()
+
     @decorators.idempotent_id('4eee1ffe-9e00-4c99-a431-0d3e0f323a8f')
     def test_list_show_update_rebuild_server_296(self):
         server = self.create_test_server(wait_until='ACTIVE')
         # Checking list API response schema.
-        self.servers_client.list_servers(detail=True)
+        self.reader_servers_client.list_servers(detail=True)
         # Checking show API response schema
-        self.servers_client.show_server(server['id'])
+        self.reader_servers_client.show_server(server['id'])
         # Checking update API response schema
         self.servers_client.update_server(server['id'])
         # Check rebuild API response schema
@@ -296,13 +283,17 @@ class ServersListShow298Test(base.BaseV2ComputeTest):
     min_microversion = '2.98'
     max_microversion = 'latest'
 
+    @classmethod
+    def setup_clients(cls):
+        super(ServersListShow298Test, cls).setup_clients()
+
     @decorators.idempotent_id('3981e496-3bf7-4015-b807-63ffee7c520c')
     def test_list_show_update_rebuild_server_298(self):
         server = self.create_test_server(wait_until='ACTIVE')
         # Check list details API response schema
-        self.servers_client.list_servers(detail=True)
+        self.reader_servers_client.list_servers(detail=True)
         # Check show API response schema
-        self.servers_client.show_server(server['id'])
+        self.reader_servers_client.show_server(server['id'])
         # Checking update API response schema
         self.servers_client.update_server(server['id'])
         # Check rebuild API response schema
@@ -321,13 +312,17 @@ class ServersListShow2100Test(base.BaseV2ComputeTest):
     min_microversion = '2.100'
     max_microversion = 'latest'
 
+    @classmethod
+    def setup_clients(cls):
+        super(ServersListShow2100Test, cls).setup_clients()
+
     @decorators.idempotent_id('2c3a8270-e6f7-4400-af0f-db003c117e48')
     def test_list_show_rebuild_update_server_2100(self):
         server = self.create_test_server(wait_until='ACTIVE')
         # Checking list API response schema.
-        self.servers_client.list_servers(detail=True)
+        self.reader_servers_client.list_servers(detail=True)
         # Checking show API response schema
-        self.servers_client.show_server(server['id'])
+        self.reader_servers_client.show_server(server['id'])
         # Checking update API response schema
         self.servers_client.update_server(server['id'])
         waiters.wait_for_server_status(self.servers_client,
